@@ -156,7 +156,17 @@ var data_obj = dataUtils.data[data_id];
         data_obj["_X"]=inputs["X"].value;
         data_obj["_Y"]=inputs["Y"].value;
     }
-    if (tmapp["ISS_viewer"].world._items.length == 0) {
+    // Check if image is already fake:
+    var recompute_background_img = false;
+    if (tmapp["ISS_viewer"].world.getItemCount() == 0) {
+        recompute_background_img = true;
+    }
+    else {
+        if (tmapp["ISS_viewer"].world.getItemAt(0).source.getTileUrl(0,0,0) == null) {
+            var recompute_background_img = true;
+        }
+    }
+    if (recompute_background_img) {
         function getMax(arr) {
             let len = arr.length; let max = -Infinity;
             while (len--) { max = +arr[len] > max ? +arr[len] : max; }
@@ -186,21 +196,28 @@ var data_obj = dataUtils.data[data_id];
             maxY = getMax(arr);
         }
         // We load an empty image at the size of the data.
-
-        console.log("maxX, maxY", maxX, maxY);
-        tmapp["ISS_viewer"].addTiledImage ({
-            tileSource: {
-                getTileUrl: function(z, x, y){return null},
-                height: parseInt(maxY*1.06),
-                width:  parseInt(maxX*1.06),
-                tileSize: 256,
-            },
-            opacity: 0,
-            x: -0.02,
-            y: -0.02
-        })
-        setTimeout (function() {dataUtils.updateViewOptions(data_id)},50);
-        return;
+        if (tmapp["ISS_viewer"].world.getItemCount() > 0) {
+            if (tmapp["ISS_viewer"].world.getItemAt(0).source.height != parseInt(maxY*1.06) || tmapp["ISS_viewer"].world.getItemAt(0).source.width != parseInt(maxX*1.06)){
+                tmapp["ISS_viewer"].close();
+                setTimeout (function() {dataUtils.updateViewOptions(data_id)},50);
+                return;
+            }
+        }
+        else {
+            tmapp["ISS_viewer"].addTiledImage ({
+                tileSource: {
+                    getTileUrl: function(z, x, y){return null},
+                    height: parseInt(maxY*1.06),
+                    width:  parseInt(maxX*1.06),
+                    tileSize: 256,
+                },
+                opacity: 0,
+                x: -0.02,
+                y: -0.02
+            })
+            setTimeout (function() {dataUtils.updateViewOptions(data_id)},50);
+            return;
+        }
     }
     //this will be trickier since trees need to be made and also a menu
     
@@ -222,6 +239,7 @@ var data_obj = dataUtils.data[data_id];
     if (radios["cb_gr"].checked) { // Color by group
         data_obj["_cb_col"]=null;
         data_obj["_cb_cmap"]=null;
+        data_obj["_cb_gr_dict"]=inputs["cb_gr_dict"].value;
     }
     else if (radios["cb_col"].checked) { // Color by marker
         if (inputs["cb_col"].value != "null") {
@@ -239,6 +257,7 @@ var data_obj = dataUtils.data[data_id];
     }
     // Use piecharts column
     data_obj["_pie_col"]=(radios["pie_check"].checked ? inputs["pie_col"].value : null);
+    data_obj["_pie_dict"]=inputs["pie_dict"].value;
     if (data_obj["_pie_col"]=="null") {
         interfaceUtils.alert("No piechart column selected. Impossible to update view.");return;
     }
@@ -253,8 +272,14 @@ var data_obj = dataUtils.data[data_id];
     if (data_obj["_shape_col"]=="null") {
         interfaceUtils.alert("No shape column selected. Impossible to update view.");return;
     }
-    // Marker opacity
+    // Use opacity column
+    data_obj["_opacity_col"]=(radios["opacity_check"].checked ? inputs["opacity_col"].value : null);
+    if (data_obj["_opacity_col"]=="null") {
+        interfaceUtils.alert("No opacity column selected. Impossible to update view.");return;
+    }
     data_obj["_opacity"]=inputs["opacity"].value;
+    // Tooltip
+    data_obj["_tooltip_fmt"]=inputs["tooltip_fmt"].value;
     
     //this function veryfies if a tree with these features exist and doesnt recreate it
     dataUtils.makeQuadTrees(data_id);
@@ -297,7 +322,7 @@ dataUtils.createMenuFromCSV = function(data_id,datumExample) {
     namesymbols.forEach((drop)=>{
         if(drop=="cb_cmap") return; //if its colormaps dont fill it with csv but with d3 luts which are already there
         if(drop=="shape_fixed") return; //if its shapes dont fill it with csv but with shape symbols which are already there
-        if(drop=="scale_factor" || drop=="shape_gr_dict" || drop=="cb_gr_dict" || drop=="opacity") return; //not dropdowns
+        if(drop=="scale_factor" || drop=="shape_gr_dict" || drop=="cb_gr_dict" || drop=="opacity" || drop=="pie_dict" || drop=="tooltip_fmt") return; //not dropdowns
         if (!alldrops[drop]) return;
         alldrops[drop].innerHTML = "";
         var option = document.createElement("option");
